@@ -60,9 +60,12 @@
 #include <QHeaderView>
 #include <QPointer>
 
-typedef KParts::GenericFactory<Part> Factory;
+typedef KParts::GenericFactory<Ark::Part> Factory;
 K_EXPORT_COMPONENT_FACTORY(libarkpart, Factory)
 
+namespace Ark
+{
+
 Part::Part(QWidget *parentWidget, QObject *parent, const QStringList& args)
         : KParts::ReadWritePart(parent), m_model(new ArchiveModel(this)), m_previewDir(0), m_busy(false),
         m_jobTracker(NULL)
@@ -97,7 +100,7 @@ Part::Part(QWidget *parentWidget, QObject *parent, const QStringList& args)
     connect(this, SIGNAL(ready()),
             this, SLOT(setReadyGui()));
     connect(this, SIGNAL(completed()),
-            this, SLOT(setWindowTitleFromArchive()));
+            this, SLOT(setFileNameFromArchive()));
 
     m_statusBarExtension = new KParts::StatusBarExtension(this);
 
@@ -435,9 +438,14 @@ void Part::setBusyGui()
     updateActions();
 }
 
-void Part::setWindowTitleFromArchive()
+void Part::setFileNameFromArchive()
 {
-    emit setWindowCaption(url().fileName());
+    QString prettyName = url().fileName();
+
+    m_infoPanel->setPrettyFileName(prettyName);
+    m_infoPanel->updateWithDefaults();
+
+    emit setWindowCaption(prettyName);
 }
 
 void Part::slotPreview()
@@ -697,3 +705,5 @@ void Part::slotDeleteFiles()
     registerJob(job);
     job->start();
 }
+
+} // namespace Ark
