@@ -147,7 +147,7 @@ KeysManager::KeysManager(QWidget *parent)
 	connect(goToDefaultKey, SIGNAL(triggered(bool)), SLOT(slotGotoDefaultKey()));
 	goToDefaultKey->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_Home));
 
-	s_kgpgEditor = new KgpgEditor(parent, imodel, Qt::Dialog, goToDefaultKey->shortcut(), true);
+	s_kgpgEditor = new KgpgEditor(this, imodel, Qt::Dialog);
 	s_kgpgEditor->setAttribute(Qt::WA_DeleteOnClose, false);
 
 	// this must come after kserver, preferences, and openEditor are created
@@ -537,7 +537,7 @@ void KeysManager::showKeyManager()
 
 void KeysManager::slotOpenEditor()
 {
-	KgpgEditor *kgpgtxtedit = new KgpgEditor(this, imodel, Qt::Window, goToDefaultKey->shortcut());
+	KgpgEditor *kgpgtxtedit = new KgpgEditor(this, imodel, Qt::Window);
 
 	connect(kgpgtxtedit, SIGNAL(refreshImported(QStringList)), imodel, SLOT(refreshKeys(QStringList)));
 	connect(kgpgtxtedit, SIGNAL(encryptFiles(KUrl::List)), this, SIGNAL(encryptFiles(KUrl::List)));
@@ -1214,7 +1214,7 @@ void KeysManager::checkList()
 		changeMessage(i18n("Group member"), 0);
 		break;
 	default:
-		kDebug(3125) << "Oops, unmatched type value" << exportList.at(0)->getType();
+		kDebug(2100) << "Oops, unmatched type value" << exportList.at(0)->getType();
 	}
 }
 
@@ -1719,7 +1719,7 @@ void KeysManager::keyproperties()
 		break;
 	}
 	default:
-		kDebug(3125) << "Oops, called with invalid item type" << cur->getType();
+		kDebug(2100) << "Oops, called with invalid item type" << cur->getType();
 	}
 }
 
@@ -1971,7 +1971,7 @@ void KeysManager::signLoop()
 				uid = "1";
 		}
 
-		kDebug(3125) << "Sign process for key:" << keyCount + 1 << "on a total of" << signList.count() << "id" << keyid << "uid" << uid;
+		kDebug(2100) << "Sign process for key:" << keyCount + 1 << "on a total of" << signList.count() << "id" << keyid << "uid" << uid;
 
 		KgpgInterface *interface = new KgpgInterface();
 		interface->signKey(keyid, globalkeyID, globalisLocal, globalChecked, m_isterminal, uid);
@@ -2636,8 +2636,7 @@ KeysManager::clipDecrypt()
 		return;
 	}
 
-	KgpgEditor *kgpgtxtedit = new KgpgEditor(this, imodel, 0, goToDefaultKey->shortcut());
-	kgpgtxtedit->setAttribute(Qt::WA_DeleteOnClose);
+	KgpgEditor *kgpgtxtedit = new KgpgEditor(this, imodel, 0);
 	connect(this, SIGNAL(fontChanged(QFont)), kgpgtxtedit, SLOT(slotSetFont(QFont)));
 	kgpgtxtedit->view->editor->setPlainText(cliptext);
 	kgpgtxtedit->view->slotDecode();
@@ -2654,8 +2653,7 @@ KeysManager::clipSign()
 		return;
 	}
 
-	KgpgEditor *kgpgtxtedit = new KgpgEditor(this, imodel, 0, goToDefaultKey->shortcut());
-	kgpgtxtedit->setAttribute(Qt::WA_DeleteOnClose);
+	KgpgEditor *kgpgtxtedit = new KgpgEditor(this, imodel, 0);
 	connect(kgpgtxtedit->view, SIGNAL(verifyFinished()), kgpgtxtedit, SLOT(closeWindow()));
 
 	kgpgtxtedit->view->slotSignVerify(cliptext);
