@@ -21,6 +21,7 @@
 #include "kgpginterface.h"
 #include "kgpgsettings.h"
 #include "convert.h"
+#include <KGlobal>
 #include <KLocale>
 
 KGpgItemModel::KGpgItemModel(QObject *parent)
@@ -131,7 +132,7 @@ KGpgItemModel::data(const QModelIndex &index, int role) const
 		}
 	case KEYCOLUMN_EXPIR:
 		if (role == Qt::DisplayRole)
-			return node->getExpiration();
+			return KGlobal::locale()->formatDate(node->getExpiration(), KLocale::ShortDate);
 		break;
 	case KEYCOLUMN_SIZE:
 		switch (role) {
@@ -153,7 +154,7 @@ KGpgItemModel::data(const QModelIndex &index, int role) const
 		break;
 	case KEYCOLUMN_CREAT:
 		if (role == Qt::DisplayRole)
-			return node->getCreation();
+			return KGlobal::locale()->formatDate(node->getCreation(), KLocale::ShortDate);
 		break;
 	case KEYCOLUMN_ID:
 		if (role == Qt::DisplayRole)
@@ -214,7 +215,7 @@ KGpgItemModel::addGroup(const QString &name, const KGpgKeyNodeList &keys)
 }
 
 void
-KGpgItemModel::delNode(const KGpgNode *node)
+KGpgItemModel::delNode(KGpgNode *node)
 {
 	emit layoutAboutToBeChanged();
 	delete node;
@@ -408,14 +409,7 @@ KGpgItemModel::isDefaultKey(const KGpgNode *node) const
 void
 KGpgItemModel::fixPersistentIndexes()
 {
-	if (persistentIndexList().isEmpty())
-		return;
-
-	QModelIndexList newidx;
-
-	for (int i = 0; i < persistentIndexList().count(); i++) {
-		QModelIndex idx = persistentIndexList().at(i);
-
+	foreach (const QModelIndex idx, persistentIndexList()) {
 		if (!idx.isValid())
 			continue;
 
@@ -434,9 +428,7 @@ KGpgItemModel::fixPersistentIndexes()
 void
 KGpgItemModel::invalidateIndexes(KGpgNode *nd)
 {
-	for (int i = 0; i < persistentIndexList().count(); i++) {
-		QModelIndex idx = persistentIndexList().at(i);
-
+	foreach (const QModelIndex idx, persistentIndexList()) {
 		KGpgNode *n = nodeForIndex(idx);
 
 		if (n != nd)
