@@ -1,7 +1,7 @@
 /*
     This file is part of the Okteta Kakao module, part of the KDE project.
 
-    Copyright 2006-2008 Friedrich W. H. Kossebau <kossebau@kde.org>
+    Copyright 2006-2009 Friedrich W. H. Kossebau <kossebau@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -22,6 +22,8 @@
 
 #include "kreplacedialog.h"
 
+// controller
+#include "replacetool.h"
 //  lib
 #include <kbytearraylineedit.h>
 // KDE
@@ -36,9 +38,9 @@
 #include <QtGui/QLayout>
 
 
-
-KReplaceDialog::KReplaceDialog( QWidget *parent )
- : KAbstractFindDialog( parent )
+KReplaceDialog::KReplaceDialog( ReplaceTool* tool, QWidget* parent )
+  : KAbstractFindDialog( parent ),
+    mTool( tool )
 {
     setCaption( i18nc("@title:window","Replace Bytes") );
     setButtonGuiItem( Ok, KGuiItem( i18nc("@action;button", "&Replace"), "edit-find-replace",
@@ -48,15 +50,13 @@ KReplaceDialog::KReplaceDialog( QWidget *parent )
                             "the bytes you entered above are searched for within "
                             "the byte array and any occurrence is replaced with "
                             "the replacement bytes.")) );
-    setModal( true );
 
     setupFindBox();
 
     // replace term
-    QGroupBox *ReplaceBox = new QGroupBox( i18nc("@title:group","Replace by"), mainWidget() );
+    QGroupBox *ReplaceBox = new QGroupBox( i18nc("@title:group","Replace By"), mainWidget() );
 
     QVBoxLayout *ReplaceBoxLayout = new QVBoxLayout;
-    ReplaceBoxLayout->setSpacing( spacingHint() );
 
     QLabel *EditLabel = new QLabel( i18nc("@label:textbox","Replacing bytes:"), ReplaceBox );
     ReplaceDataEdit = new KByteArrayLineEdit( ReplaceBox );
@@ -77,6 +77,9 @@ KReplaceDialog::KReplaceDialog( QWidget *parent )
     PromptCheckBox->setWhatsThis( i18nc("@info:whatsthis","Ask before replacing each match found.") );
 
     setupCheckBoxes( PromptCheckBox );
+
+    enableButtonOk( false );
+    setModal( true );
 }
 
 
@@ -97,6 +100,29 @@ void KReplaceDialog::setCharCodec( const QString &codecName )
 }
 
 
-KReplaceDialog::~KReplaceDialog() {}
+void KReplaceDialog::slotButtonClicked( int button )
+{
+    if( button != KDialog::Ok )
+        KAbstractFindDialog::slotButtonClicked( button );
+    else
+    {
+        hide();
 
-#include "kreplacedialog.moc"
+        mTool->setSearchData( data() );
+        mTool->setReplaceData( replaceData() );
+        mTool->setIgnoreCase( ignoreCase() );
+        mTool->setDoPrompt( prompt() );
+
+        mTool->replace( direction(), fromCursor(), inSelection() );
+    }
+}
+
+void KReplaceDialog::showEvent( QShowEvent* showEvent )
+{
+    KAbstractFindDialog::showEvent( showEvent );
+
+    setInSelection( mTool->hasSelectedData() );
+    setCharCodec( mTool->charCodingName() );
+}
+
+KReplaceDialog::~KReplaceDialog() {}
