@@ -1,7 +1,7 @@
 /*
     This file is part of the Okteta Kakao module, part of the KDE project.
 
-    Copyright 2008 Friedrich W. H. Kossebau <kossebau@kde.org>
+    Copyright 2008-2009 Friedrich W. H. Kossebau <kossebau@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -29,33 +29,37 @@
 
 namespace KHECore {
 class AbstractByteArrayModel;
+class CharCodec;
 }
 
+
 class SearchJob : public QObject // not yet: KJob
 {
   Q_OBJECT
 
   public:
     SearchJob( const KHECore::AbstractByteArrayModel *model,
-               const QByteArray &searchData, int startIndex, bool findForward );
+               const QByteArray &searchData, int startIndex, bool findForward, bool ignoreCase, const QString& charCodecName );
+    virtual ~SearchJob();
 
   public:
     int exec();
 
+  protected:
+    int indexOfIgnoreCase();
+    int lastIndexOfIgnoreCase();
+
   protected Q_SLOTS:
     void onBytesSearched();
 
   protected:
     const KHECore::AbstractByteArrayModel *mByteArrayModel;
 
-    const QByteArray mSearchData;
+    QByteArray mSearchData;
     int mStartIndex;
     bool mFindForward;
+    bool mIgnoreCase;
+    const KHECore::CharCodec* mCharCodec;
 };
 
-inline SearchJob::SearchJob( const KHECore::AbstractByteArrayModel *model,
-               const QByteArray &searchData, int startIndex, bool findForward )
- : mByteArrayModel( model ), mSearchData( searchData ), mStartIndex( startIndex), mFindForward( findForward )
-{}
-
 #endif
