@@ -1,7 +1,7 @@
 /*
     This file is part of the Okteta Kakao module, part of the KDE project.
 
-    Copyright 2006-2008 Friedrich W. H. Kossebau <kossebau@kde.org>
+    Copyright 2006-2009 Friedrich W. H. Kossebau <kossebau@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -50,6 +50,9 @@ class ViewConfigController : public AbstractXmlGuiController
     void toggleOffsetColumn( bool on );
     void toggleValueCharColumns( int visibleColunms );
 
+    void onValueCodingChanged( int valueCoding );
+    void onCharCodecChanged( const QString& charCodecName );
+
   protected:
     KByteArrayDisplay* mByteArrayDisplay;
 
